@@ -415,6 +415,11 @@ int mqtt3_db_backup(struct mosquitto_db *db, bool cleanup, bool shutdown)
 
 	fclose(db_fptr);
 
+#ifdef WIN32
+	if(remove(db->config->persistence_filepath) != 0){
+		goto error;
+	}
+#endif
 	if(rename(outfile, db->config->persistence_filepath) != 0){
 		goto error;
 	}
