@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2010-2013 Roger Light <roger@atchoo.org>
+Copyright (c) 2010-2014 Roger Light <roger@atchoo.org>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -168,8 +168,13 @@ static int _sub_topic_tokenise(const char *subtopic, struct _sub_token **topics)
 		new_topic->topic = _mosquitto_strdup("");
 		if(!new_topic->topic) goto cleanup;
 
-		*topics = new_topic;
-		tail = new_topic;
+		if(tail){
+			tail->next = new_topic;
+			tail = tail->next;
+		}else{
+			*topics = new_topic;
+			tail = new_topic;
+		}
 	}
 
 	len = strlen(subtopic);
@@ -181,8 +186,13 @@ static int _sub_topic_tokenise(const char *subtopic, struct _sub_token **topics)
 		new_topic->topic = _mosquitto_strdup("");
 		if(!new_topic->topic) goto cleanup;
 
-		*topics = new_topic;
-		tail = new_topic;
+		if(tail){
+			tail->next = new_topic;
+			tail = tail->next;
+		}else{
+			*topics = new_topic;
+			tail = new_topic;
+		}
 
 		start = 1;
 	}else{
